Struct ExecutionRequestTopic
pub struct ExecutionRequestTopic<'a> {
executions: ExecutionsTopic<'a>,
execution_id: &'a str,
payload_format: Option<PayloadFormat>,
}Expand description
Represents the MQTT topic where command execution requests are published.
Fields
executions: ExecutionsTopic<'a>execution_id: &'a strpayload_format: Option<PayloadFormat>Implementations
impl<'a> ExecutionRequestTopic<'a>
impl<'a> ExecutionRequestTopic<'a>
pub const fn new(
prefix: &'a str,
device_type: DeviceType,
device_id: &'a str,
execution_id: &'a str,
payload_format: Option<PayloadFormat>,
) -> Self
pub const fn new( prefix: &'a str, device_type: DeviceType, device_id: &'a str, execution_id: &'a str, payload_format: Option<PayloadFormat>, ) -> Self
Creates a new execution request topic.
pub const fn execution_id(self) -> &'a str
pub const fn execution_id(self) -> &'a str
Returns the execution ID segment of the topic.
pub const fn payload_format(self) -> Option<PayloadFormat>
pub const fn payload_format(self) -> Option<PayloadFormat>
Returns the payload format segment of the topic, if any.
None indicates a generic payload format. With MQTTv5 the payload
format can be read from the payload format property.
pub const fn with_payload_format(self, format: Option<PayloadFormat>) -> Self
pub const fn with_payload_format(self, format: Option<PayloadFormat>) -> Self
Returns a copy of this topic with the given payload format.
pub fn parse(topic: &'a str) -> Result<Self>